#!/usr/bin/python
# -*- coding: utf-8 -*-

__version__ = (0, 8, 0)
__author__ = "Rafał Furmański"
__contact__ = "r.furmanski@gmail.com"
__homepage__ = "http://github.com/r4fek/django-cassandra-engine"
__docformat__ = "markdown"
